#[repr(C)]pub struct SNAudioFileAnalyzer { /* private fields */ }Available on crate feature
SNAnalyzer only.Implementations
sourceimpl SNAudioFileAnalyzer
impl SNAudioFileAnalyzer
pub unsafe fn initWithURL_error( this: Allocated<Self>, url: &NSURL ) -> Result<Id<Self>, Id<NSError>>
pub unsafe fn init(this: Allocated<Self>) -> Id<Self>
pub unsafe fn addRequest_withObserver_error( &self, request: &ProtocolObject<dyn SNRequest>, observer: &ProtocolObject<dyn SNResultsObserving> ) -> Result<(), Id<NSError>>
Available on crate features
SNRequest and SNResult only.pub unsafe fn removeRequest(&self, request: &ProtocolObject<dyn SNRequest>)
Available on crate feature
SNRequest only.pub unsafe fn removeAllRequests(&self)
pub unsafe fn analyze(&self)
pub unsafe fn analyzeWithCompletionHandler( &self, completion_handler: &Block<dyn Fn(Bool)> )
Available on crate feature
block2 only.pub unsafe fn cancelAnalysis(&self)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.