pub unsafe trait SNRequest: NSObjectProtocol { }Available on crate feature
SNRequest only.Expand description
The base protocol to which analysis requests conform
An analysis request is a configuration that defines the analysis the client wishes to perform on the audio stream. Each request has a corresponding result type, which contains information describing the analysis results. This protocol is designed for all requests provided by the framework to conform to, and shouldn’t be conformed to by client objects.
See also Apple’s documentation